==> fs_moodle5-00-02_1-8-14_20130318.zip: moodle/lib/fs_moodle/fs_status/fs_filelist.php <==
<?php
    // PHP
    $filelist[] = "lib/fs_moodle/boneheadcheck.php";
    $filelist[] = "lib/fs_moodle/chat.php";
    $filelist[] = "lib/fs_moodle/error.php";
    $filelist[] = "lib/fs_moodle/fs_backup.php";
    $filelist[] = "lib/fs_moodle/fs_config_option_lib.php";
    $filelist[] = "lib/fs_moodle/fs_deprecatedlib.php";
    $filelist[] = "lib/fs_moodle/fs_index.php";
    $filelist[] = "lib/fs_moodle/fs_index_later.php";
    $filelist[] = "lib/fs_moodle/fs_lib.js";
    $filelist[] = "lib/fs_moodle/fs_lib.php";
    $filelist[] = "lib/fs_moodle/fs_lib_first.php";
    $filelist[] = "lib/fs_moodle/fs_no_override.php";
    $filelist[] = "lib/fs_moodle/fs_override.php";
    $filelist[] = "lib/fs_moodle/fs_recentActivity.php";
    $filelist[] = "lib/fs_moodle/fs_renderer.php";
    $filelist[] = "lib/fs_moodle/jp_lib.php";
//  $filelist[] = "lib/fs_moodle/mimetypeList.pdf"; // fs_moodle5以降は削除
//  $filelist[] = "lib/fs_moodle/mimetypeList.xls"; // fs_moodle5以降は削除
    $filelist[] = "lib/fs_moodle/pdf2jpeg.php";
    $filelist[] = "lib/fs_moodle/Readme.txt";
    $filelist[] = "lib/fs_moodle/rsslib.php";
    $filelist[] = "lib/fs_moodle/send2me.php";
    $filelist[] = "lib/fs_moodle/unique_login.php";
    $filelist[] = "lib/fs_moodle/version.php";
    // mail2blog
    $filelist[] = "lib/fs_moodle/mail2blog/lib.php";
    $filelist[] = "lib/fs_moodle/mail2blog/CodeZine/MailDecoder.class.php";
    $filelist[] = "lib/fs_moodle/mail2blog/CodeZine/CodeZone_OriginalCodes.zip";
    // fs_status
    $filelist[] = "lib/fs_moodle/fs_status/antiword_test.doc";
    $filelist[] = "lib/fs_moodle/fs_status/backupexceptioncheck.php";
    $filelist[] = "lib/fs_moodle/fs_status/bomchecker.php";
    $filelist[] = "lib/fs_moodle/fs_status/fs_cfg_strings.php";
    $filelist[] = "lib/fs_moodle/fs_status/fs_filelist.php";
    $filelist[] = "lib/fs_moodle/fs_status/fs_switch_strings.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_assignment.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_backup.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_basicconfig.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_blog.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_blog_mailcheck.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_calendar.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_chat.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_course.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_editor.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_forum.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_globalsearch.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_grade.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_message.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_mnet.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_nanogong.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_language.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_original.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_quiz.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_server.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_user_login.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_wiki.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsconfig_output.php";
    $filelist[] = "lib/fs_moodle/fs_status/guestlogincoursecheck.php";
    $filelist[] = "lib/fs_moodle/fs_status/index.php";
    $filelist[] = "lib/fs_moodle/fs_status/help.php";
    $filelist[] = "lib/fs_moodle/fs_status/lib.php";
    $filelist[] = "lib/fs_moodle/fs_status/menu.php";
    $filelist[] = "lib/fs_moodle/fs_status/mimecheck.php";  // fs_moodle5以降追加(fsc_basicconfig.phpで使用)
    $filelist[] = "lib/fs_moodle/fs_status/output_lib.php";
    $filelist[] = "lib/fs_moodle/fs_status/xpdf_test.pdf";
    // mobile_mode
    $filelist[] = "lib/mobilemode/lib.php";
    $filelist[] = "lib/mobilemode/mobile_cookie.js";
    // mod/forum
if (fs_get_major_version() < 2.0)
    $filelist[] = "mod/forum/view_unmailed.php";
    // user/filters
    if ($version >= 2007101500) {
if (fs_get_major_version() < 2.0)
        $filelist[] = "user/filters/user_preferences.php";
if (fs_get_major_version() < 2.0)
        $filelist[] = "user/filters/user_preferences_yesno.php";
    }
    // K-12向け日本語言語パックに対する暫定的な対策（将来的にはlanglistとhelplistで対応）
    $filelist[] = "lib/fs_moodle/lang/ja_g01_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g02_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g03_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g04_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g05_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g06_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g09_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g01/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g02/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g03/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g04/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g05/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g06/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g09/langconfig.php";

    // Language
    $langlist[] = "fs_moodle.php";
    $langlist[] = "block_updated_blogs.php";
    $langlist[] = "block_quickmail.php";
    $langlist[] = "editor.php";

    // Help
    $helplist[] = "boneheadcheck.html";
    $helplist[] = "calendar_allday.html";
    $helplist[] = "displayunmailedposts.html";
    $helplist[] = "forumdump.html";
    $helplist[] = "mobilemode.html";
    $helplist[] = "pdf2jpeg.html";
    $helplist[] = "send2me.html";
    $helplist[] = "trialreading.html";
    $helplist[] = "blogexport.html";
    $helplist[] = "settingofeventcolor.html";
?>

==> fs_moodle5-00-04_2-2-11_20140423.zip: moodle/lib/fs_moodle/fs_status/fs_filelist.php <==
<?php
    // PHP
    $filelist[] = "lib/fs_moodle/boneheadcheck.php";
    $filelist[] = "lib/fs_moodle/chat.php";
    $filelist[] = "lib/fs_moodle/error.php";
    $filelist[] = "lib/fs_moodle/fs_backup.php";
    $filelist[] = "lib/fs_moodle/fs_config_option_lib.php";
    $filelist[] = "lib/fs_moodle/fs_deprecatedlib.php";
    $filelist[] = "lib/fs_moodle/fs_index.php";
    $filelist[] = "lib/fs_moodle/fs_index_later.php";
    $filelist[] = "lib/fs_moodle/fs_lib.js";
    $filelist[] = "lib/fs_moodle/fs_lib.php";
    $filelist[] = "lib/fs_moodle/fs_lib_first.php";
    $filelist[] = "lib/fs_moodle/fs_no_override.php";
    $filelist[] = "lib/fs_moodle/fs_override.php";
    $filelist[] = "lib/fs_moodle/fs_recentActivity.php";
    $filelist[] = "lib/fs_moodle/fs_renderer.php";
    $filelist[] = "lib/fs_moodle/jp_lib.php";
//  $filelist[] = "lib/fs_moodle/mimetypeList.pdf"; // fs_moodle5以降は削除
//  $filelist[] = "lib/fs_moodle/mimetypeList.xls"; // fs_moodle5以降は削除
    $filelist[] = "lib/fs_moodle/pdf2jpeg.php";
    $filelist[] = "lib/fs_moodle/Readme.txt";
    $filelist[] = "lib/fs_moodle/rsslib.php";
    $filelist[] = "lib/fs_moodle/send2me.php";
    $filelist[] = "lib/fs_moodle/unique_login.php";
    $filelist[] = "lib/fs_moodle/version.php";
    // mail2blog
    $filelist[] = "lib/fs_moodle/mail2blog/lib.php";
    $filelist[] = "lib/fs_moodle/mail2blog/CodeZine/MailDecoder.class.php";
    $filelist[] = "lib/fs_moodle/mail2blog/CodeZine/CodeZone_OriginalCodes.zip";
    // fs_status
    $filelist[] = "lib/fs_moodle/fs_status/antiword_test.doc";
    $filelist[] = "lib/fs_moodle/fs_status/backupexceptioncheck.php";
    $filelist[] = "lib/fs_moodle/fs_status/bomchecker.php";
    $filelist[] = "lib/fs_moodle/fs_status/fs_cfg_strings.php";
    $filelist[] = "lib/fs_moodle/fs_status/fs_filelist.php";
    $filelist[] = "lib/fs_moodle/fs_status/fs_switch_strings.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_assignment.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_backup.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_basicconfig.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_blog.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_blog_mailcheck.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_calendar.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_chat.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_course.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_editor.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_forum.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_globalsearch.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_grade.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_message.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_mnet.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_nanogong.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_language.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_original.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_quiz.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_server.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_user_login.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsc_wiki.php";
    $filelist[] = "lib/fs_moodle/fs_status/fsconfig_output.php";
    $filelist[] = "lib/fs_moodle/fs_status/guestlogincoursecheck.php";
    $filelist[] = "lib/fs_moodle/fs_status/index.php";
    $filelist[] = "lib/fs_moodle/fs_status/help.php";
    $filelist[] = "lib/fs_moodle/fs_status/lib.php";
    $filelist[] = "lib/fs_moodle/fs_status/menu.php";
    $filelist[] = "lib/fs_moodle/fs_status/mimecheck.php";  // fs_moodle5以降追加(fsc_basicconfig.phpで使用)
    $filelist[] = "lib/fs_moodle/fs_status/output_lib.php";
    $filelist[] = "lib/fs_moodle/fs_status/xpdf_test.pdf";
    // filemanager
    $filelist[] = "lib/fs_moodle/filemanager/directcopy.php"; // fs_moodle5.00.04以降追加 (Shirai017)
    // mobile_mode
    $filelist[] = "lib/mobilemode/lib.php";
    $filelist[] = "lib/mobilemode/mobile_cookie.js";
    // mod/forum
if (fs_get_major_version() < 2.0)
    $filelist[] = "mod/forum/view_unmailed.php";
    // user/filters
    if ($version >= 2007101500) {
if (fs_get_major_version() < 2.0)
        $filelist[] = "user/filters/user_preferences.php";
if (fs_get_major_version() < 2.0)
        $filelist[] = "user/filters/user_preferences_yesno.php";
    }
    // K-12向け日本語言語パックに対する暫定的な対策（将来的にはlanglistとhelplistで対応）
    $filelist[] = "lib/fs_moodle/lang/ja_g01_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g02_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g03_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g04_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g05_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g06_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g09_utf8/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g01/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g02/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g03/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g04/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g05/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g06/langconfig.php";
    $filelist[] = "lib/fs_moodle/lang/ja_g09/langconfig.php";

    // Language
    $langlist[] = "fs_moodle.php";
    $langlist[] = "block_updated_blogs.php";
    $langlist[] = "block_quickmail.php";
    $langlist[] = "editor.php";

    // Help
    $helplist[] = "boneheadcheck.html";
    $helplist[] = "calendar_allday.html";
    $helplist[] = "displayunmailedposts.html";
    $helplist[] = "forumdump.html";
    $helplist[] = "mobilemode.html";
    $helplist[] = "pdf2jpeg.html";
    $helplist[] = "send2me.html";
    $helplist[] = "trialreading.html";
    $helplist[] = "blogexport.html";
    $helplist[] = "settingofeventcolor.html";
?>
